==> tigase-server-7.1.2-sources.jar: tigase/component/modules/impl/XmppPingModule.java <==
/*
 * Tigase Jabber/XMPP Server
 * Copyright (C) 2004-2014 "Artur Hefczyc" <artur.hefczyc@tigase.org>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */
package tigase.component.modules.impl;

import tigase.component.Context;
import tigase.component.exceptions.ComponentException;
import tigase.component.modules.AbstractModule;
import tigase.criteria.Criteria;
import tigase.criteria.ElementCriteria;
import tigase.server.Packet;
import tigase.xml.Element;

public class XmppPingModule<CTX extends Context> extends AbstractModule<CTX> {

	private static final Criteria CRIT = ElementCriteria.nameType("iq", "get").add(
			ElementCriteria.name("ping", "urn:xmpp:ping"));

	public XmppPingModule() {
	}

	@Override
	public String[] getFeatures() {
		return new String[] { "urn:xmpp:ping" };
	}

	@Override
	public Criteria getModuleCriteria() {
		return CRIT;
	}

	@Override
	public void process(Packet iq) throws ComponentException {
		Packet reposnse = iq.okResult((Element) null, 0);
		write(reposnse);
	}

	public final static String ID = "urn:xmpp:ping";

}

==> tigase-server-8.5.0-20251114.185321-89-sources.jar: tigase/component/modules/impl/XmppPingModule.java <==
/*
 * Tigase XMPP Server - The instant messaging server
 * Copyright (C) 2004 Tigase, Inc. (office@tigase.com)
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, version 3 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program. Look for COPYING file in the top folder.
 * If not, see http://www.gnu.org/licenses/.
 */
package tigase.component.modules.impl;

import tigase.component.exceptions.ComponentException;
import tigase.component.modules.AbstractModule;
import tigase.criteria.Criteria;
import tigase.criteria.ElementCriteria;
import tigase.kernel.beans.Bean;
import tigase.server.Packet;
import tigase.xml.Element;

@Bean(name = XmppPingModule.ID, active = true)
public class XmppPingModule
		extends AbstractModule {

	public final static String ID = "urn:xmpp:ping";
	private static final Criteria CRIT = ElementCriteria.nameType("iq", "get")
			.add(ElementCriteria.name("ping", "urn:xmpp:ping"));

	public XmppPingModule() {
	}

	@Override
	public String[] getFeatures() {
		return new String[]{"urn:xmpp:ping"};
	}

	@Override
	public Criteria getModuleCriteria() {
		return CRIT;
	}

	@Override
	public void process(Packet iq) throws ComponentException {
		Packet reposnse = iq.okResult((Element) null, 0);
		write(reposnse);
	}

}
